@@ -68,3 +68,12 @@ someDict = dict(
     key='value',
     complex_key=[1, 2, 3],
     )
+
+
+class Slotted(object):
+
+    __slots__ = ['x', 'y']
+
+    def __init__(self, x, y):
+        self.x = x
+        self.y = y
